@@ -1,4 +1,4 @@
-/* $Id: e-PCR_main.cpp,v 1.23 2008/04/28 16:38:45 rotmistr Exp $
+/* $Id: e-PCR_main.cpp,v 1.25 2008/06/18 14:45:33 rotmistr Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -36,10 +36,12 @@
 #include <errno.h>
 #include <time.h>
 
+#include <cstdio>
 #include <memory>
 
 #ifndef STANDALONE
 #include <objtools/readers/seqdb/seqdb.hpp>
+#include <objtools/readers/seqdb/seqdbcommon.hpp>
 #endif
 
 USING_NCBI_SCOPE;
@@ -91,6 +93,7 @@ protected:
     EAlignMode m_AlignMode;
 #ifndef STANDALONE
 	bool m_blastdbs;
+	string m_gilist;
 #endif
 };
 
@@ -127,6 +130,7 @@ int CMain::Help(FILE* out)
             "(default %s)\n",stsFileHash.UnmaskPrimers()?"+":"-");
 #ifndef STANDALONE
 	fprintf(out,"\t-b +-\tInput sequences are in blastdb\n");
+	fprintf(out,"\t-l file\tLimit blastdb sequences to list of gis from the file\n");
 #endif
 	fprintf(out,"and compat-options (duplicate posix-options) are:\n");
 	fprintf(out,"\tM=##\tMargin (default %d)\n",ePCR_MARGIN_DEFAULT);
@@ -149,6 +153,7 @@ int CMain::Help(FILE* out)
             "(default %s)\n",stsFileHash.UnmaskPrimers()?"+":"-");
 #ifndef STANDALONE
 	fprintf(out,"\tB=+-\tInput sequences are in blastdb\n");
+	fprintf(out,"\tL=file\tLimit blastdb sequences to list of gis from the file\n");
 #endif
 	fprintf(out,"\t-mid\tSame as T=2\n");
     fprintf(out,"verbosity flags are (flags may be changed in future):\n"
@@ -183,7 +188,7 @@ void SetDefaultSize(CStsFileHash& stsFileHash, const char * str)
 int CMain::ParseCmdline()
 {
 	int optchar;
-	while((optchar=getopt(argc,argv,"+hVf:m:n:w:g:o:t:p:v:d:a:x:u:b:"))!=-1) {
+	while((optchar=getopt(argc,argv,"+hVf:m:n:w:g:o:t:p:v:d:a:x:u:b:l:"))!=-1) {
 		switch(optchar) {
 		case 'h': Help(); break;
 		case 'V': Version(); break;
@@ -199,13 +204,10 @@ int CMain::ParseCmdline()
 			if(strcmp(optarg,"id")==0) ofmt=2;
 			else pcrMachine.SetMargin(atoi(optarg)); 
 			break;
- 		case 'w': stsFileHash.SetHash(CHashSet(atoi(optarg),
-                                               stsFileHash.GetWordCount())); 
-        break;
+ 		case 'w': stsFileHash.SetHash(CHashSet(atoi(optarg), stsFileHash.GetWordCount())); break;
  		case 'n': m_MaxMismatch=atoi(optarg); break;
  		case 'g': m_MaxGaps=atoi(optarg); break;
- 		case 'f': stsFileHash.SetHash(CHashSet(stsFileHash.GetWordSize(),
-                                               atoi(optarg))); break;
+ 		case 'f': stsFileHash.SetHash(CHashSet(stsFileHash.GetWordSize(), atoi(optarg))); break;
  		case 'd': SetDefaultSize(stsFileHash,optarg); break;
         case 'o': ofile=optarg; break;
         case 't': ofmt=atoi(optarg); break;
@@ -215,6 +217,7 @@ int CMain::ParseCmdline()
 #ifndef STANDALONE
         case 'b': m_blastdbs=*optarg=='+'?true:*optarg=='-'?false:m_blastdbs;
             break;
+		case 'l': m_gilist = optarg; break;
 #endif
         case 'v': 
             ParseVerbose(optarg);
@@ -284,6 +287,7 @@ int CMain::ParseCmdline()
             else if(argv[optind][2]=='-') 
                 m_blastdbs = false;
             break;
+		case 'L': m_gilist = argv[optind]+2; break;
 #endif
         case 'X': 
             if(argv[optind][2]=='+') 
@@ -688,7 +692,8 @@ int CMain::Execute()
 				f!=fafiles.end(); ++f) {
 #ifndef STANDALONE
 				if( m_blastdbs ) {
-					CSeqDB seqDB( *f, CSeqDB::eNucleotide );
+					CSeqDBGiList * lst = (m_gilist.length() ? new CSeqDBFileGiList( m_gilist ) : 0 );
+					CSeqDB seqDB( *f, CSeqDB::eNucleotide, lst );
 					processor.CbkFileBegin();
 					for( CSeqDBIter i = seqDB.Begin(); i; ++i ) {
 						list<CRef<CSeq_id> > ids = seqDB.GetSeqIDs( i.GetOID() );
@@ -771,6 +776,12 @@ int main(int argc, char ** argv)
 
 /*
  * $Log: e-PCR_main.cpp,v $
+ * Revision 1.25  2008/06/18 14:45:33  rotmistr
+ * Fixed problem with -d x-X parameter being reset if -w or some others are used after it.
+ *
+ * Revision 1.24  2008/06/16 16:02:40  rotmistr
+ * *** empty log message ***
+ *
  * Revision 1.23  2008/04/28 16:38:45  rotmistr
  * Applied patch to build with gcc-4.3
  *
